@@ -1,16 +1,14 @@
 #! /usr/bin/env/python
 # -*- coding: utf-8 -*-
 
-## Copyright 1999-2008 by LivingLogic AG, Bayreuth/Germany
-## Copyright 1999-2008 by Walter Dörwald
+## Copyright 1999-2010 by LivingLogic AG, Bayreuth/Germany
+## Copyright 1999-2010 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
 ## See ll/__init__.py for the license
 
 
-from __future__ import with_statement
-
 import warnings, cStringIO
 
 from xml.etree import cElementTree
@@ -315,3 +313,14 @@ def test_expat_doctype():
 	e = parsers.parsestring('<!DOCTYPE a [<!ELEMENT a EMPTY><!--gurk-->]><a/>', parser=parsers.ExpatParser(doctype=True))
 	assert isinstance(e[0], xsc.DocType)
 	assert e[0].content == u'a' # Internal subset gets dropped
+
+
+def test_htmlparse_base():
+	e = parsers.parsestring("<a href='gurk.gif'/>", base="hurz/index.html", tidy=True)
+	e = e.walknode(html.a)[0]
+	assert unicode(e.attrs.href) == "hurz/gurk.gif"
+
+
+def test_parse_tidy_empty():
+	e = parsers.parsestring("", tidy=True)
+	assert not e
\ No newline at end of file
